

<!-- Automatically generated, uses README.qmd to modify README.md -->

# `morethemes`: more themes for matplotlib

<img src="https://github.com/JosephBARBIERDARNAL/static/blob/main/python-libs/morethemes/image.png?raw=true" alt="morethemes logo" align="right" width="150px"/>

**`morethemes`** provides themes for
[matplotlib](https://matplotlib.org/). More themes, better plots, one
line of code.

![PyPI - Downloads](https://img.shields.io/pypi/dm/morethemes)

[Documentation site](https://josephbarbierdarnal.github.io/morethemes/)

<br>

## Installation

``` bash
pip install morethemes
```

Don’t want to add **`morethemes`** as a dependency? You can either
browse the [source
code](https://github.com/JosephBARBIERDARNAL/morethemes/blob/main/morethemes/themes.py)
to find the rcParams, or use the `mt.get_rcparams("theme_name")`
function.

<br>

## Themes

**`morethemes`** offers 14 themes at the moment:

### WSJ

``` python
import morethemes as mt
mt.set_theme("wsj")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/wsj.png)](https://josephbarbierdarnal.github.io/morethemes/)

### URBAN

``` python
import morethemes as mt
mt.set_theme("urban")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/urban.png)](https://josephbarbierdarnal.github.io/morethemes/)

### MINIMAL

``` python
import morethemes as mt
mt.set_theme("minimal")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/minimal.png)](https://josephbarbierdarnal.github.io/morethemes/)

### FT

``` python
import morethemes as mt
mt.set_theme("ft")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/ft.png)](https://josephbarbierdarnal.github.io/morethemes/)

### NATURE

``` python
import morethemes as mt
mt.set_theme("nature")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/nature.png)](https://josephbarbierdarnal.github.io/morethemes/)

### ECONOMIST

``` python
import morethemes as mt
mt.set_theme("economist")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/economist.png)](https://josephbarbierdarnal.github.io/morethemes/)

### GREENWAVE

``` python
import morethemes as mt
mt.set_theme("greenwave")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/greenwave.png)](https://josephbarbierdarnal.github.io/morethemes/)

### VSCODE-DARK

``` python
import morethemes as mt
mt.set_theme("vscode-dark")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/vscode-dark.png)](https://josephbarbierdarnal.github.io/morethemes/)

### NORD

``` python
import morethemes as mt
mt.set_theme("nord")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/nord.png)](https://josephbarbierdarnal.github.io/morethemes/)

### RETRO

``` python
import morethemes as mt
mt.set_theme("retro")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/retro.png)](https://josephbarbierdarnal.github.io/morethemes/)

### LIGHTER

``` python
import morethemes as mt
mt.set_theme("lighter")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/lighter.png)](https://josephbarbierdarnal.github.io/morethemes/)

### DARKER

``` python
import morethemes as mt
mt.set_theme("darker")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/darker.png)](https://josephbarbierdarnal.github.io/morethemes/)

### YELLOWISH

``` python
import morethemes as mt
mt.set_theme("yellowish")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/yellowish.png)](https://josephbarbierdarnal.github.io/morethemes/)

### MONOBLUE

``` python
import morethemes as mt
mt.set_theme("monoblue")
```

[![](https://raw.githubusercontent.com/JosephBARBIERDARNAL/morethemes/refs/heads/main/docs/img/monoblue.png)](https://josephbarbierdarnal.github.io/morethemes/)
